@@ -4,7 +4,8 @@ from __future__ import annotations
 
 from importlib import metadata, resources
 from pathlib import Path
-from typing import cast
+from typing import Any, cast
+import configparser
 
 import requests
 import tomli
@@ -73,7 +74,7 @@ def packageInfoFromPypi(requirements: list[str]) -> list[PackageInfo]:
 	"""
 	pkgInfo = []
 	for pkg in requirements:
-		request = requests.get(f"https://pypi.org/pypi/{pkg}/json")
+		request = requests.get(f"https://pypi.org/pypi/{pkg}/json", timeout=60)
 		response = request.json()
 		info = response["info"]
 		licenseClassifier = licenseFromClassifierlist(info["classifiers"])
@@ -124,36 +125,42 @@ def getPackages(reqs: list[str]) -> list[PackageInfo]:
 	onlineReqs = packageInfoFromPypi(reqs)
 	return localReqs + onlineReqs
 
+def getClassifiersLicense() -> dict[str, Any]:
+	"""Get the package classifiers and license from "setup.cfg", "pyproject.toml" or user input
+
+	Returns:
+		dict[str, Any]: {"classifiers": list[str], "license": str}
+	"""
+	if Path("setup.cfg").exists():
+		config = configparser.ConfigParser()
+		_ = config.read("setup.cfg")
+		if "license" in config["metadata"]:
+			return config["metadata"].__dict__
+	if Path("pyproject.toml").exists():
+		pyproject = tomli.loads(Path("pyproject.toml").read_text(encoding="utf-8"))
+		tool = pyproject["tool"]
+		if "poetry" in tool:
+			return tool["poetry"]
+		if "flit" in tool:
+			return tool["flit"]["metadata"]
+	return {"classifiers": [], "license": ""}
+
+
 
 def getMyPackageLicense() -> str:
-	"""Get the pyproject data.
+	"""Get the package license from "setup.cfg", "pyproject.toml" or user input
 
 	Returns:
 		str: license name
-
-	Raises:
-		RuntimeError: Must specify a license using license spdx or classifier (tool.poetry or tool.flit)
 	"""
-	try:
-		pyproject = tomli.loads(Path("pyproject.toml").read_text(encoding="utf-8"))
-	except FileNotFoundError:
-		return input("Enter the project license")
-	tool = pyproject["tool"]
-	metaData = {"classifiers": [], "license": ""}
-	if "poetry" in tool:
-		metaData = tool["poetry"]
-	elif "flit" in tool:
-		metaData = tool["flit"]["metadata"]
-	else:
-		return input("Enter the project license")
+	metaData = getClassifiersLicense()
 	licenseClassifier = licenseFromClassifierlist(metaData.get("classifiers", []))
 	if licenseClassifier != UNKNOWN:
 		return licenseClassifier
 	if "license" in metaData:
 		return str(metaData["license"])
-	raise RuntimeError(
-		"Must specify a license using license spdx or classifier (tool.poetry or tool.flit)"
-	)
+	return input("Enter the project license")
+
 
 
 def getModuleSize(path: Path, name: str) -> int:
@@ -171,6 +178,6 @@ def getModuleSize(path: Path, name: str) -> int:
 	)
 	if size > 0:
 		return size
-	request = requests.get(f"https://pypi.org/pypi/{name}/json")
+	request = requests.get(f"https://pypi.org/pypi/{name}/json", timeout=60)
 	response = request.json()
 	return int(response["urls"][-1]["size"])
